@@ -57,3 +57,12 @@ def pae(pieces: List[bytes]) -> bytes:
         output += _le64(len(pieces[i]))
         output += pieces[i]
     return output
+
+
+def ec_public_key_compress(x: int, y: int) -> bytes:
+
+    bx = x.to_bytes(48, byteorder="big")
+    by = y.to_bytes((y.bit_length() + 7) // 8, byteorder="big")
+    s = bytearray(1)
+    s[0] = 0x02 + (by[len(by) - 1] & 1)
+    return bytes(s) + bx
